summaryrefslogtreecommitdiffstats
path: root/libtdegames/kcarddialog.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'libtdegames/kcarddialog.cpp')
-rw-r--r--libtdegames/kcarddialog.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/libtdegames/kcarddialog.cpp b/libtdegames/kcarddialog.cpp
index b6967b5b..9434b799 100644
--- a/libtdegames/kcarddialog.cpp
+++ b/libtdegames/kcarddialog.cpp
@@ -87,8 +87,8 @@ public:
TQLabel* deckLabel;
TQLabel* cardLabel;
- KIconView* deckIconView;
- KIconView* cardIconView;
+ TDEIconView* deckIconView;
+ TDEIconView* cardIconView;
TQCheckBox* randomDeck;
TQCheckBox* randomCardDir;
TQCheckBox* globalDeck;
@@ -277,7 +277,7 @@ void KCardDialog::setupDialog(bool showResizeBox)
TQGroupBox* grp1 = new TQGroupBox(1,Qt::Horizontal, i18n("Choose Backside"), plainPage());
layout->addWidget(grp1);
- d->deckIconView = new KIconView(grp1,"decks");
+ d->deckIconView = new TDEIconView(grp1,"decks");
d->deckIconView->setSpacing(8);
/*
deckIconView->setGridX(-1);
@@ -329,7 +329,7 @@ void KCardDialog::setupDialog(bool showResizeBox)
TQGroupBox* grp2 = new TQGroupBox(1,Qt::Horizontal, i18n("Choose Frontside"), plainPage());
layout->addWidget(grp2);
- d->cardIconView =new KIconView(grp2,"cards");
+ d->cardIconView =new TDEIconView(grp2,"cards");
/*
cardIconView->setGridX(36);
cardIconView->setGridY(50);
@@ -416,7 +416,7 @@ void KCardDialog::setupDialog(bool showResizeBox)
// leads to an always resizing dialog which is *very* ugly. i worked around
// this by using a TQWidget which is the only child widget of the group box.
// The other widget are managed inside this TQWidget - a stretch area on the
// right ensures that the KIconViews are not resized...
// note that the dialog is still resized if you you scale the pixmap very
// large. This is desired behaviour as i don't want to make the box even
@@ -416,7 +416,7 @@ void KCardDialog::setupDialog(bool showResizeBox)
// this by using a TQWidget which is the only child widget of the group box.
// The other widget are managed inside this TQWidget - a stretch area on the
- // right ensures that the KIconViews are not resized...
+ // right ensures that the TDEIconViews are not resized...
// note that the dialog is still resized if you you scale the pixmap very
// large. This is desired behaviour as i don't want to make the box even